:mod:`art.utils`
================
.. automodule:: art.utils

Deprecation Operations
----------------------
.. autofunction:: deprecated
.. autofunction:: deprecated_keyword_arg

Math Operations
---------------
.. autofunction:: projection
.. autofunction:: random_sphere
.. autofunction:: original_to_tanh
.. autofunction:: tanh_to_original

Label Operations
----------------
.. autofunction:: to_categorical
.. autofunction:: float_to_categorical
.. autofunction:: check_and_transform_label_format
.. autofunction:: random_targets
.. autofunction:: least_likely_class
.. autofunction:: second_most_likely_class
.. autofunction:: get_label_conf
.. autofunction:: get_labels_np_array
.. autofunction:: compute_success_array
.. autofunction:: compute_success
.. autofunction:: compute_accuracy

Dataset Operations
------------------
.. autofunction:: load_dataset
.. autofunction:: get_file
.. autofunction:: make_directory
.. autofunction:: clip_and_round
.. autofunction:: preprocess
.. autofunction:: segment_by_class
.. autofunction:: performance_diff
.. autofunction:: is_probability
